==> indigitall_flutter_plugin-2.0.2.tar.gz: android/src/main/kotlin/com/indigitall/indigitall_flutter_plugin/utils/InboxParse.kt <==
package com.indigitall.indigitall_flutter_plugin.utils

import com.indigitall.android.commons.models.CoreAction
import com.indigitall.android.commons.models.ErrorModel
import com.indigitall.android.inbox.Inbox
import com.indigitall.android.inbox.models.*
import org.json.JSONArray
import org.json.JSONException
import org.json.JSONObject

object InboxParse {
    private val ACTION_ERROR = "error"
    private val CALLBACK_GET_MESSAGE_COUNT = "callbackGetMessageCount"

    fun mapFromMessagesCount(inboxCounters: InboxCounters?): Map<String, Map<*,*>> {
        val MAP_CLICK = "click"
        val MAP_SENT = "sent"
        val MAP_DELETED = "deleted"
        val MAP_LAST_ACCESS = "lastAccess"
        val MAP_COUNT = "count"
        val map: MutableMap<String, String> = HashMap()
        try {
            inboxCounters?.click?.let { map[MAP_CLICK] = it.toString() }
            inboxCounters?.sent?.let { map[MAP_SENT] = it.toString() }
            inboxCounters?.deleted?.let { map[MAP_DELETED] = it.toString() }
            inboxCounters?.getUnread()?.let {
                it.lastAccess?.let { it1 -> map[MAP_LAST_ACCESS] = it1.toString() }
                it.getCount()?.let { it1 -> map[MAP_COUNT] = it1.toString() }
            }
        } catch (ex: Exception) {
            ex.printStackTrace()
        }
        val messageCountMap: MutableMap<String, Map<*,*>> = HashMap()
        messageCountMap[CALLBACK_GET_MESSAGE_COUNT] = map
        return messageCountMap
    }

    fun mapFromInbox(
        inbox: Inbox,
        newNotifications: ArrayList<InboxNotification>?
    ): Map<String, String>  {
        val MAP_LAST_ACCESS = "lastAccess"
        val MAP_COUNT = "count"
        val MAP_PAGESIZE = "pageSize"
        val MAP_PAGE = "numPage"
        val MAP_NOTIFICATIONS = "notifications"
        val MAP_NEW_NOTIFICAIONS = "newNotifications"
        val map: MutableMap<String, String> = HashMap()
        try {
            inbox.lastAccess?.let{map[MAP_LAST_ACCESS] = it.toString()}
            inbox.count?.let{map[MAP_COUNT] =  it.toString()}
            inbox.pageSize?.let{map[MAP_PAGESIZE] =  it.toString()}
            inbox.page?.let{map[MAP_PAGE] =  it.toString()}
            inbox.notifications?.let{map[MAP_NOTIFICATIONS] = mapArrayFromInboxNotifications(it).toString()}
            newNotifications?.let { map[MAP_NEW_NOTIFICAIONS] = mapArrayFromInboxNotifications(it).toString()}
        } catch (ex: Exception) {
            ex.printStackTrace()
        }
        return map
    }

    fun mapArrayFromInboxNotifications(inboxNotifications: ArrayList<InboxNotification>?): JSONArray {
        val MAP_ID = "id"
        val MAP_SENTAT = "sentAt"
        val MAP_STATUS = "status"
        val MAP_SENDINGID = "sendingId"
        val MAP_CAMPAIGNID = "campaignId"
        val MAP_MESSAGE = "message"
        val MAP_CATEGORY = "category"
        val array = JSONArray()
        if (inboxNotifications != null) {
            try {
                for (inboxNotification in inboxNotifications) {
                    val json = JSONObject()
                    inboxNotification.id?.let{json.put(MAP_ID, it)}
                    inboxNotification.sentAt?.let{json.put(MAP_SENTAT, it.toString())}
                    inboxNotification.status?.let{json.put(MAP_STATUS,  it.toString())}
                    inboxNotification.sendingId?.let{json.put(MAP_SENDINGID, it.toString())}
                    inboxNotification.campaignId?.let{json.put(MAP_CAMPAIGNID,  it.toString())}
                    inboxNotification.message?.let{ json.put(MAP_MESSAGE, mapFromPush(it).toString()) }
                    inboxNotification.category?.let{ json.put(MAP_CATEGORY, mapFromCategory(it).toString()) }
                    array.put(json.toString())
                }
            } catch (ex: JSONException) {
                ex.printStackTrace()
            }
        }
        return array
    }

    fun errorToMap(error: ErrorModel?): Map<*, *>{
        val map: MutableMap<String, MutableMap<String, String>> = HashMap()
        val mapError :MutableMap<String, String> = HashMap()
        error?.errorCode?.name?.let {
            error.errorMessage.errorMessage?.let{ it1 -> mapError[it] = it1}
        }
        map[ACTION_ERROR] = mapError
        return map
    }

    fun mapFromInboxNotification(inboxNotification: InboxNotification): Map<String, String>  {
        val MAP_ID = "id"
        val MAP_SENTAT = "sentAt"
        val MAP_STATUS = "status"
        val MAP_SENDINGID = "sendingId"
        val MAP_CAMPAIGNID = "campaignId"
        val MAP_MESSAGE = "message"
        val MAP_CATEGORY = "category"
        val map: MutableMap<String, String> = HashMap()
        try {
            inboxNotification.id?.let{map[MAP_ID] =  it}
            inboxNotification.sentAt?.let{map[MAP_SENTAT] =  it.toString()}
            inboxNotification.status?.let{map[MAP_STATUS] =  it.toString()}
            inboxNotification.sendingId?.let{map[MAP_SENDINGID] =  it.toString()}
            inboxNotification.campaignId?.let{map[MAP_CAMPAIGNID] =  it.toString()}
            inboxNotification.message?.let{ map[MAP_MESSAGE] = mapFromPush(it).toString() }
            inboxNotification.category?.let{ map[MAP_CATEGORY] = mapFromCategory(it).toString() }
        } catch (ex: Exception) {
            ex.printStackTrace()
        }
        return map
    }


    fun mapFromCategory(category: InboxCategory): Map<String, String>  {
        val MAP_ID = "id"
        val MAP_NAME = "name"
        val MAP_CODE = "code"
        val map: MutableMap<String, String> = HashMap()
        try {
            category.id?.let{map[MAP_ID] =  it.toString()}
            category.name?.let{map[MAP_NAME] =  it.toString()}
            category.code?.let{map[MAP_CODE] =  it.toString()}
        } catch (ex: Exception) {
            ex.printStackTrace()
        }
        return map
    }

    fun mapFromPush(push: InboxPush): JSONObject {
        val MAP_ID = "id"
        val MAP_APP_KEY = "appKey"
        val MAP_TITLE = "title"
        val MAP_BODY = "body"
        val MAP_ICON = "icon"
        val MAP_IMAGE = "image"
        val MAP_GIF = "gif"
        val MAP_LAYOUT = "layout"
        val MAP_DATA = "data"
        val MAP_SILENT = "silent"
        val MAP_SECURE_DATA = "securedData"
        val MAP_ACTION = "action"
        val MAP_BUTTONS = "buttons"
        val MAP_SENDING_ID = "sendingId"
        val MAP_CAMPAIGN_ID = "CampaignId"
        val MAP_PUSH_ID = "pushId"
        val json = JSONObject()
        try {
            push.id?.let{
                json.put(MAP_ID , push.id.toString())
                json.put(MAP_PUSH_ID, push.id.toString())
            }
            push.appKey?.let{json.put(MAP_APP_KEY, it)}
            push.title?.let{json.put(MAP_TITLE, it)}
            push.body?.let{json.put(MAP_BODY, it)}
            push.icon?.let{json.put(MAP_ICON, it)}
            push.image?.let{json.put(MAP_IMAGE, it)}
            push.gif?.let{json.put(MAP_GIF, it.toString())}
            push.layout?.let{json.put(MAP_LAYOUT,it.toString())}
            push.data?.let{json.put(MAP_DATA, it)}
            push.silent?.let{json.put(MAP_SILENT, it.toString())}
            push.action?.let{json.put(MAP_ACTION, mapFromAction(it).toString())}
            push.securedData?.let{json.put(MAP_SECURE_DATA, it)}
            push.sendingId?.let{json.put(MAP_SENDING_ID, it)}
            push.campaignId?.let{json.put(MAP_CAMPAIGN_ID, it)}

            push.buttons?.let{
                for (i in it.indices) {
                    val pushButton = it[i]
                    json.put(MAP_BUTTONS, mapFromPushButtons(pushButton).toString())
                }
            }
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return json
    }

    fun mapFromAction(pushAction: CoreAction): JSONObject {
        val MAP_DESTROY = "destroy"
        val MAP_TOPICS = "topics"
        val MAP_TYPE = "type"
        val MAP_TYPE_APP = "app"
        val MAP_TYPE_URL = "url"
        val MAP_TYPE_CALL = "call"
        val MAP_TYPE_MARKET = "market"
        val MAP_TYPE_SHARE = "share"
        val json = JSONObject()
        try {
            pushAction.isDestroy?.let{json.put(MAP_DESTROY, it.toString())}
            pushAction.topics?.let{json.put(MAP_TOPICS,it.toString())}
            pushAction.type?.let{json.put(MAP_TYPE, it.toString())}
            pushAction.app?.let{json.put(MAP_TYPE_APP, it)}
            pushAction.url?.let{json.put(MAP_TYPE_URL, it)}
            pushAction.call?.let{json.put(MAP_TYPE_CALL, it)}
            pushAction.market?.let{json.put(MAP_TYPE_MARKET, it)}
            pushAction.share?.let{json.put(MAP_TYPE_SHARE, it)}
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return json
    }

    fun mapFromPushButtons(pushButton: InboxPushButton): Map<*, *> {
        val MAP_LABEL = "label"
        val MAP_ACTION = "action"
        val MAP_TOPICS = "topics"
        val map : MutableMap<String, String> = HashMap()
        try {
            pushButton.label?.let{map[MAP_LABEL] = it}
            pushButton.action?.let{map[MAP_ACTION] = mapFromAction(it).toString()}
            pushButton.topics?.let{map[MAP_TOPICS] = it.toString()}
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return map
    }

    fun stringToMap(key: String, value: String): Map<*, *>{
        val map: MutableMap<String, String> = HashMap()
        map[key] = value
        return map
    }
}

==> indigitall_flutter_plugin-2.5.1.tar.gz: android/src/main/kotlin/com/indigitall/indigitall_flutter_plugin/utils/InboxParse.kt <==
package com.indigitall.indigitall_flutter_plugin.utils

import com.indigitall.android.commons.models.CoreAction
import com.indigitall.android.commons.models.ErrorModel
import com.indigitall.android.inbox.Inbox
import com.indigitall.android.inbox.models.*
import org.json.JSONArray
import org.json.JSONException
import org.json.JSONObject

object InboxParse {
    private val ACTION_ERROR = "error"
    private val CALLBACK_GET_MESSAGE_COUNT = "callbackGetMessageCount"

    fun mapFromMessagesCount(inboxCounters: InboxCounters?): Map<String, Map<*,*>> {
        val MAP_CLICK = "click"
        val MAP_SENT = "sent"
        val MAP_DELETED = "deleted"
        val MAP_LAST_ACCESS = "lastAccess"
        val MAP_COUNT = "count"
        val map: MutableMap<String, String> = HashMap()
        try {
            inboxCounters?.click?.let { map[MAP_CLICK] = it.toString() }
            inboxCounters?.sent?.let { map[MAP_SENT] = it.toString() }
            inboxCounters?.deleted?.let { map[MAP_DELETED] = it.toString() }
            inboxCounters?.getUnread()?.let {
                it.lastAccess?.let { it1 -> map[MAP_LAST_ACCESS] = it1.toString() }
                it.getCount()?.let { it1 -> map[MAP_COUNT] = it1.toString() }
            }
        } catch (ex: Exception) {
            ex.printStackTrace()
        }
        val messageCountMap: MutableMap<String, Map<*,*>> = HashMap()
        messageCountMap[CALLBACK_GET_MESSAGE_COUNT] = map
        return messageCountMap
    }

    fun mapFromInbox(
        inbox: Inbox,
        newNotifications: ArrayList<InboxNotification>?
    ): Map<String, String>  {
        val MAP_LAST_ACCESS = "lastAccess"
        val MAP_COUNT = "count"
        val MAP_PAGESIZE = "pageSize"
        val MAP_PAGE = "numPage"
        val MAP_NOTIFICATIONS = "notifications"
        val MAP_NEW_NOTIFICAIONS = "newNotifications"
        val map: MutableMap<String, String> = HashMap()
        try {
            inbox.lastAccess?.let{map[MAP_LAST_ACCESS] = it.toString()}
            inbox.count?.let{map[MAP_COUNT] =  it.toString()}
            inbox.pageSize?.let{map[MAP_PAGESIZE] =  it.toString()}
            inbox.page?.let{map[MAP_PAGE] =  it.toString()}
            inbox.notifications?.let{map[MAP_NOTIFICATIONS] = mapArrayFromInboxNotifications(it).toString()}
            newNotifications?.let { map[MAP_NEW_NOTIFICAIONS] = mapArrayFromInboxNotifications(it).toString()}
        } catch (ex: Exception) {
            ex.printStackTrace()
        }
        return map
    }

    fun mapArrayFromInboxNotifications(inboxNotifications: ArrayList<InboxNotification>?): JSONArray {
        val MAP_ID = "id"
        val MAP_SENTAT = "sentAt"
        val MAP_STATUS = "status"
        val MAP_SENDINGID = "sendingId"
        val MAP_CAMPAIGNID = "campaignId"
        val MAP_MESSAGE = "message"
        val MAP_CATEGORY = "category"
        val array = JSONArray()
        if (inboxNotifications != null) {
            try {
                for (inboxNotification in inboxNotifications) {
                    val json = JSONObject()
                    inboxNotification.id?.let{json.put(MAP_ID, it)}
                    inboxNotification.sentAt?.let{json.put(MAP_SENTAT, it.toString())}
                    inboxNotification.status?.let{json.put(MAP_STATUS,  it.toString())}
                    inboxNotification.sendingId?.let{json.put(MAP_SENDINGID, it.toString())}
                    inboxNotification.campaignId?.let{json.put(MAP_CAMPAIGNID,  it.toString())}
                    inboxNotification.message?.let{ json.put(MAP_MESSAGE, mapFromPush(it).toString()) }
                    inboxNotification.category?.let{ json.put(MAP_CATEGORY, mapFromCategory(it).toString()) }
                    array.put(json.toString())
                }
            } catch (ex: JSONException) {
                ex.printStackTrace()
            }
        }
        return array
    }

    fun errorToMap(error: ErrorModel?): Map<*, *>{
        val map: MutableMap<String, MutableMap<String, String>> = HashMap()
        val mapError :MutableMap<String, String> = HashMap()
        error?.errorCode?.name?.let {
            error.errorMessage.errorMessage?.let{ it1 -> mapError[it] = it1}
        }
        map[ACTION_ERROR] = mapError
        return map
    }

    fun mapFromInboxNotification(inboxNotification: InboxNotification): Map<String, String>  {
        val MAP_ID = "id"
        val MAP_SENTAT = "sentAt"
        val MAP_STATUS = "status"
        val MAP_SENDINGID = "sendingId"
        val MAP_CAMPAIGNID = "campaignId"
        val MAP_MESSAGE = "message"
        val MAP_CATEGORY = "category"
        val map: MutableMap<String, String> = HashMap()
        try {
            inboxNotification.id?.let{map[MAP_ID] =  it}
            inboxNotification.sentAt?.let{map[MAP_SENTAT] =  it.toString()}
            inboxNotification.status?.let{map[MAP_STATUS] =  it.toString()}
            inboxNotification.sendingId?.let{map[MAP_SENDINGID] =  it.toString()}
            inboxNotification.campaignId?.let{map[MAP_CAMPAIGNID] =  it.toString()}
            inboxNotification.message?.let{ map[MAP_MESSAGE] = mapFromPush(it).toString() }
            inboxNotification.category?.let{ map[MAP_CATEGORY] = mapFromCategory(it).toString() }
        } catch (ex: Exception) {
            ex.printStackTrace()
        }
        return map
    }


    fun mapFromCategory(category: InboxCategory): Map<String, String>  {
        val MAP_ID = "id"
        val MAP_NAME = "name"
        val MAP_CODE = "code"
        val map: MutableMap<String, String> = HashMap()
        try {
            category.id?.let{map[MAP_ID] =  it.toString()}
            category.name?.let{map[MAP_NAME] =  it.toString()}
            category.code?.let{map[MAP_CODE] =  it.toString()}
        } catch (ex: Exception) {
            ex.printStackTrace()
        }
        return map
    }

    fun mapFromPush(push: InboxPush): JSONObject {
        val MAP_ID = "id"
        val MAP_APP_KEY = "appKey"
        val MAP_TITLE = "title"
        val MAP_BODY = "body"
        val MAP_ICON = "icon"
        val MAP_IMAGE = "image"
        val MAP_GIF = "gif"
        val MAP_LAYOUT = "layout"
        val MAP_DATA = "data"
        val MAP_SILENT = "silent"
        val MAP_SECURE_DATA = "securedData"
        val MAP_ACTION = "action"
        val MAP_BUTTONS = "buttons"
        val MAP_SENDING_ID = "sendingId"
        val MAP_CAMPAIGN_ID = "CampaignId"
        val MAP_PUSH_ID = "pushId"
        val json = JSONObject()
        try {
            push.id?.let{
                json.put(MAP_ID , push.id.toString())
                json.put(MAP_PUSH_ID, push.id.toString())
            }
            push.appKey?.let{json.put(MAP_APP_KEY, it)}
            push.title?.let{json.put(MAP_TITLE, it)}
            push.body?.let{json.put(MAP_BODY, it)}
            push.icon?.let{json.put(MAP_ICON, it)}
            push.image?.let{json.put(MAP_IMAGE, it)}
            push.gif?.let{json.put(MAP_GIF, it.toString())}
            push.layout?.let{json.put(MAP_LAYOUT,it.toString())}
            push.data?.let{json.put(MAP_DATA, it)}
            push.silent?.let{json.put(MAP_SILENT, it.toString())}
            push.action?.let{json.put(MAP_ACTION, mapFromAction(it).toString())}
            push.securedData?.let{json.put(MAP_SECURE_DATA, it)}
            push.sendingId?.let{json.put(MAP_SENDING_ID, it)}
            push.campaignId?.let{json.put(MAP_CAMPAIGN_ID, it)}

            push.buttons?.let{
                for (i in it.indices) {
                    val pushButton = it[i]
                    json.put(MAP_BUTTONS, mapFromPushButtons(pushButton).toString())
                }
            }
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return json
    }

    fun mapFromAction(pushAction: CoreAction): JSONObject {
        val MAP_DESTROY = "destroy"
        val MAP_TOPICS = "topics"
        val MAP_TYPE = "type"
        val MAP_TYPE_APP = "app"
        val MAP_TYPE_URL = "url"
        val MAP_TYPE_CALL = "call"
        val MAP_TYPE_MARKET = "market"
        val MAP_TYPE_SHARE = "share"
        val json = JSONObject()
        try {
            pushAction.isDestroy()?.let{json.put(MAP_DESTROY, it.toString())}
            pushAction.topics?.let{json.put(MAP_TOPICS,it.toString())}
            pushAction.type?.let{json.put(MAP_TYPE, it.toString())}
            pushAction.app?.let{json.put(MAP_TYPE_APP, it)}
            pushAction.url?.let{json.put(MAP_TYPE_URL, it)}
            pushAction.call?.let{json.put(MAP_TYPE_CALL, it)}
            pushAction.market?.let{json.put(MAP_TYPE_MARKET, it)}
            pushAction.share?.let{json.put(MAP_TYPE_SHARE, it)}
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return json
    }

    fun mapFromPushButtons(pushButton: InboxPushButton): Map<*, *> {
        val MAP_LABEL = "label"
        val MAP_ACTION = "action"
        val MAP_TOPICS = "topics"
        val map : MutableMap<String, String> = HashMap()
        try {
            pushButton.label?.let{map[MAP_LABEL] = it}
            pushButton.action?.let{map[MAP_ACTION] = mapFromAction(it).toString()}
            pushButton.topics?.let{map[MAP_TOPICS] = it.toString()}
        } catch (ex: JSONException) {
            ex.printStackTrace()
        }
        return map
    }

    fun stringToMap(key: String, value: String): Map<*, *>{
        val map: MutableMap<String, String> = HashMap()
        map[key] = value
        return map
    }
}
